<?php
/* Copyright (C) 2003		Rodolphe Quiedeville	<rodolphe@quiedeville.org>
 * Copyright (C) 2005-2006	Laurent Destailleur		<eldy@users.sourceforge.net>
 * Copyright (C) 2012		Regis Houssin			<regis.houssin@capnetworks.com>
 * Copyright (C) 2012       Marcos García           <marcosgdf@gmail.com>
 * Copyright (C) 2015       Benoit Bruchard         <benoitb21@gmail.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * \file       htdocs/core/modules/dons/html_cerfafr1158003.modules.php
 * \ingroup    don
 * \brief      Formulaire de don
 */
require_once DOL_DOCUMENT_ROOT.'/core/modules/dons/modules_don.php';
require_once DOL_DOCUMENT_ROOT.'/compta/dons/class/don.class.php';
require_once DOL_DOCUMENT_ROOT.'/core/lib/company.lib.php';


/**
 *	Class to generate document for subscriptions
 */
class html_cerfafr1158003 extends ModeleDon
{
    /**
     *  Constructor
     *
     *  @param      DoliDb		$db      Database handler
     */
    function __construct($db)
    {
        global $conf,$langs;

        $this->db = $db;
        $this->name = "cerfafr1158003";
        $this->description = $langs->trans('DonationsReceiptModel');

        // Dimension page pour format A4
        $this->type = 'html';
    }


	/**
	 * 	Return if a module can be used or not
	 *
	 *  @return	boolean     true if module can be used
	 */
	function isEnabled()
	{
		return true;
	}


    /**
     *  Write the object to document file to disk
     *
     *	@param	Don			$don	        Donation object
     *  @param  Translate	$outputlangs    Lang object for output language
     *	@return	int             			>0 if OK, <0 if KO
     */
    function write_file($don,$outputlangs)
    {
		global $user,$conf,$langs,$mysoc;

		$now=dol_now();
		$id = (! is_object($don)?$don:'');

		if (! is_object($outputlangs)) $outputlangs=$langs;

		$outputlangs->load("main");
		$outputlangs->load("dict");
		$outputlangs->load("companies");
		$outputlangs->load("bills");
		$outputlangs->load("products");
		$outputlangs->load("donations");

        if (! empty($conf->don->dir_output))
        {
			// Definition de l'objet $don (pour compatibilite ascendante)
        	if (! is_object($don))
        	{
	            $don = new Don($this->db);
	            $ret=$don->fetch($id);
	            $id=$don->id;
			}

			// Definition de $dir et $file
			if (! empty($don->specimen))
			{
				$dir = $conf->don->dir_output;
				$file = $dir . "/SPECIMEN.html";
			}
			else
			{
				$donref = dol_sanitizeFileName($don->ref);
				$dir = $conf->don->dir_output . "/" . get_exdir($donref,2);
				$file = $dir . "/" . $donref . ".html";
			}

	        if (! file_exists($dir))
	        {
	            if (dol_mkdir($dir) < 0)
	            {
	                $this->error=$langs->trans("ErrorCanNotCreateDir",$dir);
	                return -1;
	            }
	        }

            if (file_exists($dir))
            {
            	$formclass = new Form($this->db);

            	//This is not the proper way to do it but $formclass->form_modes_reglement
            	//prints the translation instead of returning it
            	if ($don->modepaiementid)
            	{
            		$formclass->load_cache_types_paiements();
            		$paymentmode = $formclass->cache_types_paiements[$don->modepaiementid]['label'];
            	}
            	else $paymentmode = '';
				
				if ($don->modepaiementid==7){
				$ModePaiement = '<td width="33%"><INPUT type="checkbox" disabled="true" > Remise d\'espèces</td><td width="33%"><INPUT type="checkbox" disabled="true" checked> Chèque</td><td width="33%"><INPUT type="checkbox" disabled="true" > Virement, prélèvement, carte bancaire</td>';
				}
				else if ($don->modepaiementid==4){
				$ModePaiement = '<td width="33%"><INPUT type="checkbox" disabled="true" checked> Remise d\'espèces</td><td width="33%"><INPUT type="checkbox" disabled="true"> Chèque</td><td width="33%"><INPUT type="checkbox" disabled="true" > Virement, prélèvement, carte bancaire</td>';
				}
				else if ($don->modepaiementid==2 OR $don->modepaiementid==3 OR $don->modepaiementid==6){
				$ModePaiement = '<td width="33%"><INPUT type="checkbox" disabled="true"> Remise d\'espèces</td><td width="33%"><INPUT type="checkbox" disabled="true"> Chèque</td><td width="33%"><INPUT type="checkbox" disabled="true" checked> Virement, prélèvement, carte bancaire</td>';
				} 
				else 
				{
				$ModePaiement = '<td width="33%"><INPUT type="checkbox" disabled="true"> Remise d\'espèces</td><td width="33%"><INPUT type="checkbox" disabled="true"> Chèque</td><td width="33%"><INPUT type="checkbox" disabled="true" > Virement, prélèvement, carte bancaire</td>';
				}
				
				if (empty($don->societe))
				{
				$CodeDon = '<td width="33%"><INPUT type="checkbox" disabled="true" checked> 200 du CGI</td><td width="33%"><INPUT type="checkbox" disabled="true" > 238 bis du CGI</td><td width="33%"><INPUT type="checkbox" disabled="true" > 885-0 V bis A du CGI</td>';
				}
				else
				{
				$CodeDon = '<td width="33%"><INPUT type="checkbox" disabled="true" > 200 du CGI</td><td width="33%"><INPUT type="checkbox" disabled="true" checked> 238 bis du CGI</td><td width="33%"><INPUT type="checkbox" disabled="true" > 885-0 V bis A du CGI</td>';
				}
				

		        // Defini contenu
		        $donmodel=DOL_DOCUMENT_ROOT ."/core/modules/dons/html_cerfafr1158003.html";
		        $form = implode('', file($donmodel));
		        $form = str_replace('__REF__',$don->id,$form);
		        $form = str_replace('__DATE__',dol_print_date($don->date,'day',false,$outputlangs),$form);
		        //$form = str_replace('__IP__',$user->ip,$form); // TODO $user->ip not exist
		        $form = str_replace('__AMOUNT__',$don->amount,$form);
				$form = str_replace('__AMOUNTLETTERS__',chiffre_en_lettre($don->amount),$form);
		        $form = str_replace('__CURRENCY__',$outputlangs->transnoentitiesnoconv("Currency".$conf->currency),$form);
		        $form = str_replace('__CURRENCYCODE__',$conf->currency,$form);
		        $form = str_replace('__MAIN_INFO_SOCIETE_NOM__',$mysoc->name,$form);
		        $form = str_replace('__MAIN_INFO_SOCIETE_ADDRESS__',$mysoc->address,$form);
		        $form = str_replace('__MAIN_INFO_SOCIETE_ZIP__',$mysoc->zip,$form);
		        $form = str_replace('__MAIN_INFO_SOCIETE_TOWN__',$mysoc->town,$form);
				$form = str_replace('__MAIN_INFO_SOCIETE_NOTE__',$mysoc->note_private,$form);
		        $form = str_replace('__DONATOR_FIRSTNAME__',$don->firstname,$form);
				$form = str_replace('__DONATOR_LASTNAME__',$don->lastname,$form);
				$form = str_replace('__DONATOR_SOCIETE__',$don->societe,$form);
				$form = str_replace('__DONATOR_STATUT__',$don->statut,$form);
		        $form = str_replace('__DONATOR_ADDRESS__',$don->address,$form);
		        $form = str_replace('__DONATOR_ZIP__',$don->zip,$form);
		        $form = str_replace('__DONATOR_TOWN__',$don->town,$form);
		        $form = str_replace('__PAYMENTMODE_LIB__  ', $paymentmode,$form);
				$form = str_replace('__ModePaiement__', $ModePaiement,$form);
		        $form = str_replace('__NOW__',dol_print_date($now,'',false,$outputlangs),$form);
		        $form = str_replace('__CodeDon__',$CodeDon,$form);
		        $form = str_replace('__Name__',$outputlangs->trans("Name"),$form);
		        $form = str_replace('__Town__',$outputlangs->trans("Town"),$form);
		        $form = str_replace('__Date__',$outputlangs->trans("Date"),$form);
		        $form = str_replace('__Signature__',$outputlangs->trans("Signature"),$form);

		        // Sauve fichier sur disque
		        dol_syslog("html_cerfafr1158003::write_file $file");
		        $handle=fopen($file,"w");
		        fwrite($handle,$form);
		        fclose($handle);
				if (! empty($conf->global->MAIN_UMASK))
					@chmod($file, octdec($conf->global->MAIN_UMASK));

		        return 1;
            }
            else
            {
                $this->error=$langs->trans("ErrorCanNotCreateDir",$dir);
                return 0;
            }
	    }
        else
        {
            $this->error=$langs->trans("ErrorConstantNotDefined","DON_OUTPUTDIR");
            return 0;
		}
        $this->error=$langs->trans("ErrorUnknown");
        return 0;   // Erreur par defaut
    }
	
	
}

function chiffre_en_lettre($montant, $devise1='', $devise2='')
{
    if(empty($devise1)) $dev1='euros';
    else $dev1=$devise1;
    if(empty($devise2)) $dev2='centimes';
    else $dev2=$devise2;
    $valeur_entiere=intval($montant);
    $valeur_decimal=intval(round($montant-intval($montant), 2)*100);
    $dix_c=intval($valeur_decimal%100/10);
    $cent_c=intval($valeur_decimal%1000/100);
    $unite[1]=$valeur_entiere%10;
    $dix[1]=intval($valeur_entiere%100/10);
    $cent[1]=intval($valeur_entiere%1000/100);
    $unite[2]=intval($valeur_entiere%10000/1000);
    $dix[2]=intval($valeur_entiere%100000/10000);
    $cent[2]=intval($valeur_entiere%1000000/100000);
    $unite[3]=intval($valeur_entiere%10000000/1000000);
    $dix[3]=intval($valeur_entiere%100000000/10000000);
    $cent[3]=intval($valeur_entiere%1000000000/100000000);
    $chif=array('', 'un', 'deux', 'trois', 'quatre', 'cinq', 'six', 'sept', 'huit', 'neuf', 'dix', 'onze', 'douze', 'treize', 'quatorze', 'quinze', 'seize', 'dix sept', 'dix huit', 'dix neuf');
        $secon_c='';
        $trio_c='';
    for($i=1; $i<=3; $i++){
        $prim[$i]='';
        $secon[$i]='';
        $trio[$i]='';
        if($dix[$i]==0){
            $secon[$i]='';
            $prim[$i]=$chif[$unite[$i]];
        }
        else if($dix[$i]==1){
            $secon[$i]='';
            $prim[$i]=$chif[($unite[$i]+10)];
        }
        else if($dix[$i]==2){
            if($unite[$i]==1){
            $secon[$i]='vingt et';
            $prim[$i]=$chif[$unite[$i]];
            }
            else {
            $secon[$i]='vingt';
            $prim[$i]=$chif[$unite[$i]];
            }
        }
        else if($dix[$i]==3){
            if($unite[$i]==1){
            $secon[$i]='trente et';
            $prim[$i]=$chif[$unite[$i]];
            }
            else {
            $secon[$i]='trente';
            $prim[$i]=$chif[$unite[$i]];
            }
        }
        else if($dix[$i]==4){
            if($unite[$i]==1){
            $secon[$i]='quarante et';
            $prim[$i]=$chif[$unite[$i]];
            }
            else {
            $secon[$i]='quarante';
            $prim[$i]=$chif[$unite[$i]];
            }
        }
        else if($dix[$i]==5){
            if($unite[$i]==1){
            $secon[$i]='cinquante et';
            $prim[$i]=$chif[$unite[$i]];
            }
            else {
            $secon[$i]='cinquante';
            $prim[$i]=$chif[$unite[$i]];
            }
        }
        else if($dix[$i]==6){
            if($unite[$i]==1){
            $secon[$i]='soixante et';
            $prim[$i]=$chif[$unite[$i]];
            }
            else {
            $secon[$i]='soixante';
            $prim[$i]=$chif[$unite[$i]];
            }
        }
        else if($dix[$i]==7){
            if($unite[$i]==1){
            $secon[$i]='soixante et';
            $prim[$i]=$chif[$unite[$i]+10];
            }
            else {
            $secon[$i]='soixante';
            $prim[$i]=$chif[$unite[$i]+10];
            }
        }
        else if($dix[$i]==8){
            if($unite[$i]==1){
            $secon[$i]='quatre-vingts et';
            $prim[$i]=$chif[$unite[$i]];
            }
            else {
            $secon[$i]='quatre-vingt';
            $prim[$i]=$chif[$unite[$i]];
            }
        }
        else if($dix[$i]==9){
            if($unite[$i]==1){
            $secon[$i]='quatre-vingts et';
            $prim[$i]=$chif[$unite[$i]+10];
            }
            else {
            $secon[$i]='quatre-vingts';
            $prim[$i]=$chif[$unite[$i]+10];
            }
        }
        if($cent[$i]==1) $trio[$i]='cent';
        else if($cent[$i]!=0 || $cent[$i]!='') $trio[$i]=$chif[$cent[$i]] .' cents';
    }
     
     
$chif2=array('', 'dix', 'vingt', 'trente', 'quarante', 'cinquante', 'soixante', 'soixante-dix', 'quatre-vingts', 'quatre-vingts dix');
    $secon_c=$chif2[$dix_c];
    if($cent_c==1) $trio_c='cent';
    else if($cent_c!=0 || $cent_c!='') $trio_c=$chif[$cent_c] .' cents';
     
    if(($cent[3]==0 || $cent[3]=='') && ($dix[3]==0 || $dix[3]=='') && ($unite[3]==1))
        $somme = $trio[3]. '  ' .$secon[3]. ' ' . $prim[3]. ' million ';
    else if(($cent[3]!=0 && $cent[3]!='') || ($dix[3]!=0 && $dix[3]!='') || ($unite[3]!=0 && $unite[3]!=''))
        $somme = $trio[3]. ' ' .$secon[3]. ' ' . $prim[3]. ' millions ';
    else
        $somme = $trio[3]. ' ' .$secon[3]. ' ' . $prim[3];
     
    if(($cent[2]==0 || $cent[2]=='') && ($dix[2]==0 || $dix[2]=='') && ($unite[2]==1))
        $somme = $somme.' mille ';
    else if(($cent[2]!=0 && $cent[2]!='') || ($dix[2]!=0 && $dix[2]!='') || ($unite[2]!=0 && $unite[2]!=''))
        $somme = $somme. $trio[2]. ' ' .$secon[2]. ' ' . $prim[2]. ' milles ';
    else
        $somme = $somme. $trio[2]. ' ' .$secon[2]. ' ' . $prim[2];
     
    $somme = $somme. $trio[1]. ' ' .$secon[1]. ' ' . $prim[1];
     
    $somme = $somme. ' '. $dev1 .' ' ;
     
    if(($cent_c=='0' || $cent_c=='') && ($dix_c=='0' || $dix_c==''))
        return $somme. ' et z&eacute;ro '. $dev2;
    else
        return $somme. $trio_c. ' ' .$secon_c. ' ' . $dev2;
		
}

?>
